蚯蚓<>渠散儿,渠算儿
蜻蜓<>叮叮猫儿,丁丁猫儿
蚱蜢<>爪蜢儿,爪母儿
跳蚤<>革蚤,格蚤
知了<>拎阿子,丁阿子,金阿子,金啊子
青蛙<>瞎块儿,克妈,缺块儿,缺妈,麻拐
蛔虫<>潮冲,巢冲
蟑螂<>灶妈子,偷油婆
小鸟<>雀雀儿
蛐蛐儿<>照鸡儿
脑袋<>哈老壳,老壳,脑壳
胳肢窝<>瞎孔,狭孔
手肘<>手倒管儿,受倒管儿,手倒拐儿
膝盖<>克西头儿,客西头儿,磕西头儿
又高有胖<>肥弄弄的,高耸耸的
非常脏<>烦造造的
很短<>短处处的
光溜溜的<>逛的
很软<>趴唧唧的
很少<>低低嘎嘎儿,低低嘎嘎
很野<>飞叉叉的
大惊小怪<>惊抓抓的
很糊涂<>矿西西的
很直<>琛
非常帅<>琛抖,登独
非常漂亮<>琛抖,登独
冷不防的<>雾独独
发神经<>神戳戳
粘稠的<>念栋栋
俗气的<>俗杂杂的
灼伤般的疼<>火瞟瞟的
挤过来<>共过来
不动了<>不拗老
喂进去<>莽进去
掐<>咔
碰到了<>款到老
聊天<>摆龙门阵,吹侉侉,吹垮垮
吹牛<>冒皮皮,冲壳子,提劲倒把,提劲,绕包,吹垮垮
摔跤<>达扑爬,答葡爬
摔跟头<>达扑爬
敲一下头<>考可可儿,考可转儿
精神不集中<>打王逛
紧挨着<>扒到,吧到
舀饭）<>瓦饭
跨过来<>喀过来,过来
跑<>调,条
翻跟斗<>翻羊角转儿,翻羊角砖儿
夹菜<>捻菜,怜菜,练菜
打呼噜<>扯仆汉,扯仆酣
用肘移走<>副开
吃得多<>骇得,嗨得
结束<>腰台／收秤／杀鸽,腰抬／收秤／杀鸽,收秤,煞角
耍赖<>板旋儿
挣扎<>板旋儿,板
挠痒痒<>哈技跟儿,哈,哈即跟儿
脚崴了<>脚入老
吮吸<>菊
试一下<>告哈儿
丢失了<>舌老
伸过来<>琛过来,痴过来,琛过来／痴过来
跺脚<>读脚
掰<>月,灭,咩,篾
压下去<>逞下去
过滤<>必,笔,壁
补上<>状起,幢起,装起
猜到<>俺到
看到<>雀到
相抵了<>兑老
板脸<>马起脸
打瞌睡<>爪瞌睡,拽瞌睡
踢球<>爪球
打扫<>杀铁
翻<>操
假装<>假巴意思
撒尿<>窝料,哦尿尿
脏<>唻噻,挖爪,楼搜,哇抓,龌龊
这里<>勒里
很<>嘿
角落<>卡卡角角,卡卡各各
一点点<>低低噶噶儿
热闹<>闹热
多少<>好多
神经病<>神头儿,神撮撮
完了<>洗白,除脱
坐车时叫停<>杀一脚
擦<>吱
顶,磋的意思<>剁
傻傻的<>瓜西西
无事乱逛<>灯晃,灯儿晃
结巴<>夹舌子,夹色子
眼神不好<>暴眼
骂<>决,绝,诀
溜走<>闪色子,梭
丢脸<>臊皮,脏班子,扫皮
说谎<>日白,扯靶子,扯把子,扯谎
就是<>斗室
对<>对头
很强<>霸道惨老
念或修理人<>清候
坐便车<>搭巴巴车
好的,行<>要得
不得了<>妖不到台,霸道,洋气
好吓人<>好黑人
很傻<>黑哈
搭讪<>搭飞白
不要这样<>莫恁个,莫棱个
很油的样子<>油济济
发一声<>歇
哭<>歇
送<>拼
碰到<>款到
发三声<>扛
盖上<>扛
鞋跟<>鞋子等等儿,孩子,骇子等等儿
咯脚<>恩脚
浪费油<>背(bēi)油,背油
猜测<>古
削笔刀<>车笔刀,车笔刀儿
变质<>哈猴
责备<>里骂,里麻
油垢<>甲甲
幸好<>希得好,西得好
排队<>排轮子,排列子
滑梯<>梭梭滩儿,索索滩儿
缝<>债起,再起／撩起
很亮<>亮瓦瓦
动<>拗
俗气<>俗杂杂的,俗杂杂哩
灼伤疼<>火瞟瞟的
舀饭<>瓦饭
移走<>副开
压住<>俺到
相抵<>兑老
没有了<>洗白
挂了<>除脱
踩在脚下来回擦几下<>喱
做车时叫停<>杀一脚
擦)<>吱
顶<>夺
磋<>夺
走神<>打王逛
吗<>迈
吧<>撒
块头大<>登读
去<>切,气,克
修理<>清候,弄
好的<>要得
行<>要得
干什么<>爪子,啥子,撒子
很油<>油济济
郁闷<>背油
不听话<>杯话
喝水<>喝开开
睡觉<>睡告告
吃饭<>吃莽莽
哄孩子<>筐歪歪
臀部<>作登儿,罗兜
又高又胖<>高耸耸的,肥懂懂的
很野的样子<>飞叉叉的
手脚不停地动<>拗
不耿直<>差火,锤子,杂豁豁哩
不义气<>锤子
老婆<>堂客
司机<>车分儿
厨师<>炊哥
孩子<>幺儿
笨<>宝器
痞子<>杂皮
无赖<>杂皮
停车<>杀一脚
小祖宗<>仙人板板
长相不错<>登读
这个谁来解释<>打飞白
身上的油垢<>甲甲
哄孩子睡觉<>筐歪歪
我说真的<>正南齐北
强大<>吃皮
厉害<>吃皮,霸道惨老
以为<>麦到
很多人吃饭不给钱就闪人<>吃跑堂
上面<>高头,高底
下面<>底甲,觉底,脚脚
刷子<>刷把
簸箕<>烧鸡
铲子<>喘喘
铁锹<>喘喘
锤子<>钉锤
很不够意思<>牙刷
勺<>瓢瓢
筐<>萝都
赶面杖<>赶面棒
围嘴<>奔奔儿
内裤<>摇裤儿
腻<>商人
吃厌了<>商人
不想吃油腻<>闷油
完毕<>归于
厕所<>茅司
整洁<>岑投
利索<>岑投
托<>梅子
倒霉<>背时
聪明<>空哨,灵醒,精灵
有知识<>空哨
脑子好使<>灵光
怕老婆<>巴耳朵,耙耳朵
撑腰<>扎起
哥们<>兄弟伙
义气<>落教
出事了<>翻船
不好解决<>妖不到台
说大话<>提劲,牛批
很棒<>提劲
说假话<>绕包
艳丽<>妖艳
容易<>耙皮
便宜<>耙豁,相因
讨厌<>烦
恶心<>烦
肮脏<>烦
欺骗<>豁
内向的人<>闷声儿
流氓<>杂皮
政治小人<>杂皮
社会渣滓<>杂皮
想呕吐<>翻胃
不利索<>日布龙耸
不整洁<>日布龙耸
整理<>打整,清候
收拾<>打整
制服人<>打整
底部<>独独,读读儿
起劲<>憨展劲
很行<>透德行
一头雾水<>旷眉旷眼
阿姨<>娘娘
试一试<>告哈儿
补齐<>装起
板着脸<>马起脸
出问题<>扯拐
有毛病了<>扯拐
翻跟头<>鹞子翻叉
捣蛋<>千翻儿
调皮<>千翻儿
令人讨厌<>讨嫌
故意<>刁阻,刁住
失信<>涮坛子
不讲信用<>涮坛子
爸爸<>老汉,老汉儿
傻瓜<>瓜娃子,哈子,哈儿,哈麻批,哈板儿,木冬瓜,苕货,宝器,方脑壳
假惺惺的<>假巴意思
失败<>洗白
栽了<>洗白
脏)<>挖爪
旮旯<>喀喀各各
被人解决了<>除脱
完蛋了<>除脱
停一下车<>刹一脚
粗口<>仙人板板
骂骂咧咧<>仙人板板
游手好闲<>灯儿晃
无意识<>打王逛
大而鼓出眼睛<>暴眼
黑高大<>登独
肥壮<>登独
下不来台<>扫皮
撒谎<>扯把子
就<>豆
查看<>清候
调查<>清候
管<>理麻
干预<>理麻
气质好<>洋气
新奇<>洋气
别这样<>莫恁个
很油腻<>油济济
赠送<>拼
了不起<>霸道
肉<>嘎嘎
拽<>行市
有能力<>行市
好<>对头,要得
要得<>对头
没问题<>对头
正合心意<>巴心不得
正想这样<>巴心不得
说正经的<>正南其北
不扯闲<>正南其北
失业<>锄脱
失恋<>锄脱
有矛盾<>卯
很差<>暴挫
很丑<>爆搓,暴挫
很笨<>暴挫
满意舒服<>安逸
不用谢<>不要
虚伪<>假打
夹起来<>拈起来
小子<>鬼儿
马上<>哈哈儿
多少钱<>好多钱
什么<>么子,啥子
沿着路走<>扒到路走
全部<>一哈
谈恋爱<>耍朋友
闲聊天<>摆龙门阵
骗傻子<>麻哈儿嗦
怎么样<>浪个
<>浪个
怎样<>浪个
漂亮<>乖桑桑,乖
傻<>哈,哈戳戳,邙,苕,瓜
真的是<>恩是
一会儿<>哈哈儿
看美女<>打望
打<>锤,弄
男性生殖器<>锤子
操<>弄
背夫偷汉<>龟儿子
傻儿子<>瓜吆儿
姑姑<>娘娘
小叔<>幺爸
哥哥<>拐子
弟弟<>兄弟
奶奶<>婆婆
男孩<>儿娃子,男娃儿
女孩<>女娃子,妹娃子,女娃儿
娘娘腔<>假妹仔,假女儿
假小子<>儿马婆
小混混<>少幺爸,天棒
太保<>少幺爸,天棒
小太妹<>飞石
老大<>扛把子
老鸨<>院妈娘
妓女<>梭叶子
乞丐<>告花子
伙计<>邱二
挑夫<>棒棒
二楞子<>宝器
搞砸<>撮锅漏
嘴馋<>五香嘴,好吃狗儿
瘦而弱不禁风的人<>豁飘
胖人<>闷墩儿
瘦人<>啷杆儿
矮胖<>矮大杵,黄桶
大饼脸<>泡粑脸
鞋拔子脸<>瓦刀脸
猪腰子脸<>瓦刀脸
额窄颧骨高而下巴宽<>秤砣脸
额头特大而脸下部窄小<>磬锤脑壳
眼睛又小又细<>拉丝眼
拼命挣扎<>板命
死不认账<>打横爬,拉稀摆带,板旋儿
说话不算数<>打横爬,拉稀摆带,板旋儿
枪毙<>敲砂罐
背后说人坏话<>出言语,犯言,下烂药
整人<>医闷鸡
被整的人只能自认倒霉<>医闷鸡
到达<>拢
自欺欺人<>捏倒鼻子哄眼睛
生病卧床或者装病<>装狗儿
溺爱<>惯伺
纵容<>惯伺
奢侈<>玩格
怎么<>啷凯,啷个,啷闷
这样<>恁个
这<>勒
什么时候<>好久,哪阵
开始<>架势,架蔑,尬势,尬事
开小差<>打王逛,打王广广
爆骂<>日绝
特别丑<>爆搓,搓-丑
显摆<>夺洋
帅<>撑投,登独
牛B<>洋盘,洋气,不摆老,行事,霸道
纠纷<>扯皮
没完没了<>紧倒
使劲<>莽起,搂实,黑起
强迫人做某事<>古倒
蹲下<>估倒
戳<>居,夺
穿小鞋<>夹毛居
吓<>黑
水坑<>水凼凼
使弯曲<>月,篾
告密<>点水
当场揭穿<>抵黄
唱对台戏<>抵黄
请客<>吃胡汉三,吃福喜
占便宜<>捡葩和
白痴<>吃抹货
白看<>看抹货
服气<>落教
闹矛盾<>割裂
不好相处<>割不得人
照顾<>矜佑
悍妇<>恶鸡婆
妻管严<>葩耳朵
阴险<>老阴脉
沉默<>闷生儿
这么<>恁个
的<>哩
了<>哒,老
谁<>哪个
人家<>别个
别人<>别个
一下<>一哈
没有<>么得
可以<>要得
着<>起,倒
底下<>底哈
被<>遭
像<>呛
玩<>耍
吃<>奇,恰
喋喋不休<>批款卵款,批侉卵侉
看<>盯
钻<>共
塞<>莽
疯闹嬉戏<>费
缠着不放<>拗倒
死缠烂打<>扭倒费
卡住<>款倒
跨过去<>卡
摔<>达
跌倒<>达
正面摔倒<>达扑爬
粘<>巴
贴<>巴
紧挨<>巴倒
舀<>瓦
抠<>欧
估摸着<>谙倒
揉<>渠
磨蹭<>渠
放<>科
送给<>拼给
调换<>调
推<>哈,护,薅
试<>告
按<>逞
完蛋<>洗白
死<>洗白
抵消<>兑老
闪电<>扯霍闪
说话<>开腔
瞎说<>开黄腔
搭话<>搭白
插话<>搭飞白
到处看<>打望
拍马屁<>舔肥
强迫<>古倒
刺<>居,夺
请客大出血<>吃胡汉三,吃福喜
白吃<>吃抹货
照料<>矜佑
馋<>潮
大便<>屙粑粑
小便<>屙尿
挤兑<>夹毛居
压<>摁
盖住<>扛
手淫<>打手冲
摩擦<>姿
扇耳光<>产
耳光<>耳死
丢<>蛇
遗失<>蛇
装蒜<>装莽
装傻<>装莽
吃好的<>打牙祭
搬运<>盘
哄骗<>豁
关系破裂<>搞铆,拉爆
消灭<>除脱
抹杀<>抹脱
忽略<>抹脱
胳肢<>哈济跟儿
发怒<>红眉毛绿眼睛
把拖把等往水里戳<>咚
搞假<>掺假水
疼爱<>稀奇
宠爱<>稀奇
打鼾<>扯扑汗
说梦话<>发梦冲
爷爷<>嗲嗲
外婆<>家家,家婆
外公<>家公
曾祖父母<>祖祖
岳父<>老亲爷,岳老头儿,泰山
岳母<>老亲妈,泰水,岳老婆婆儿
公公<>老人公
婆婆<>婆子妈
舅妈<>姆姆
伯母<>伯妈
女长辈<>姻伯
对年轻女子的亲热称呼<>妹儿
对年轻男子的亲热称呼<>崽儿
把事情搞砸的人<>撮锅漏
嘴馋的人<>五香嘴,好吃狗儿
尿床<>流尿狗儿
弱不禁风<>豁飘
胖而结实的人<>莽子,闷墩儿
高而瘦的人<>啷杆儿
矮而胖的人<>矮大杵,黄桶
老好人<>糯米老头
外地人<>外哈,外码子
沉默的人<>闷生儿
地痞无赖<>滚龙,烂眼儿,杂皮
游手好闲的人<>滚龙,烂眼儿,杂皮
抬杠<>弯搬匠,咬卵匠
大嘴巴<>岔嘴巴
包不住话<>岔嘴巴
长舌妇<>翻嘴婆
中年人<>爆眼子老婆婆儿,爆眼子老头儿
技术不好<>撇火药,黄司机
火急火燎<>猫师兄,毛哥
脾气急躁<>猫师兄,毛哥
扒手<>二级钳工,摸包贼,摸包客
土匪<>棒老二,棒客,毛子
倒霉晦气的人<>霉冬瓜
瘸子<>掰子
O型腿<>盘脚
X型腿<>拐脚
左撇子<>左拐子
丑男<>蹉跎
矬人<>蹉跎
糊涂虫<>旷二妹
螳螂<>猴三儿
蟋蟀<>灶鸡儿
天牛<>牵牛
蜈蚣<>雷公虫
虱子<>蛇子
萤火虫<>亮花虫儿
放屁虫<>屁巴虫
蝽<>屁巴虫
蜣螂<>推屎爬
金龟子<>金木耳
瓢虫<>新姑娘,花姑娘
蚂蚁<>蚂丫子
鼻涕虫<>旋巴虫
螺<>螺蛳
蜗牛<>山螺蛳
毛毛虫<>活拉子,猪儿虫,八角丁,袢梁狗儿
蛇<>烂草梭,干黄鳝,啷巴杆儿,高黄鳝
泥鳅<>鱼鳅
王八<>团鱼
癞蛤蟆<>癞克妈,癞格宝
鲫鱼<>鲫壳儿
鲇鱼<>鲇巴啷,胡子鲇
黄颡鱼<>黄腊丁
鲮鱼<>水米子
鲢鱼<>白鲢
胖头鱼<>花鲢
螃蟹<>螃凯,螃海
老鼠<>耗唧唧,耗儿,耗子
鱼<>摆摆,鱼摆摆
鸡<>鸡咯咯
公鸡<>鸡公
母鸡<>鸡母
鹅<>威威
很臭<>帮臭八臭,滂臭,帮臭
可怜<>造孽,造业
差<>崴,撇
不好<>崴,撇
帅气<>撑投,登独
丑<>搓
很好<>洋盘,洋气,不摆老,行事,霸道
舒服<>安逸,巴适
没必要<>不消
好看<>灵醒
老土<>苕
庸俗<>苕
调皮捣蛋<>千翻儿
规矩老实<>指笨
奇怪<>怪头怪脑,怪眉日眼
阴阳怪气<>怪头怪脑,怪眉日眼
不友好<>绿眉绿眼,横眉秋眼
麻烦<>弯酸
磨磨蹭蹭<>裸连
拖泥带水<>裸连
背地里<>阴倒
邋遢<>楼搜,唻噻
胖的<>肉墩墩哩,肉唧唧哩
胖胖的<>肉墩墩哩,肉唧唧哩
瘦的<>瘦掐掐哩
瘦瘦的<>瘦掐掐哩
长长的<>长梭梭哩
短短的<>短杵杵哩
软<>葩
很烫<>飞烫
很冷<>冰巴子冷
很多很大<>苕大八大
很少很小<>低低嘎嘎
没来由的<>白知八知
不知不觉的<>白知八知
很浓稠<>练咚咚哩
糊涂<>旷兮兮哩,雾独独哩
神经质<>神戳戳哩
疑神疑鬼<>神戳戳哩
啥乎乎的<>哈戳戳哩
爽快<>耿直
够义气<>耿直
不地道<>差火,锤子,杂豁豁哩
很红<>绯红
苍白<>卡白
很白<>迅白
黝黑<>区黑
光线很暗<>黑区妈空
很黄<>黄焦焦哩,焦黄
血淋淋的<>血古淋当
硬邦邦的<>硬痴夺棒
很柔软<>葩唧唧哩
凶巴巴的<>一凶二恶
焦躁不安<>毛焦火辣
灼痛<>火漂火辣
阵痛<>阴痛阴痛
不安分<>寒贱,手寒脚贱
爱招惹他人<>寒贱,手寒脚贱
大块头<>大墩墩
小个子<>小壳钻儿
活泼<>经蹦
精力好<>经蹦
皱巴巴的<>重皮高
平顺<>撑撑展展
睫毛<>眼眨毛
眼泪<>眼睛水
污垢<>甲甲
腋窝<>峡孔夹
手指<>手指母
脚趾<>脚趾母
大拇指<>大指母
中指<>中指母
小指<>幺指母
腿<>侉子
肘子<>膀
屁股<>箩篼,楼沟子,沟子,坐墩儿
胸部<>咪咪
