渠散儿<>蚯蚓
丁丁猫儿<>蜻蜓
爪蜢儿<>蚱蜢
格蚤<>跳蚤
金啊子<>知了
瞎块儿<>青蛙
巢冲<>蛔虫
偷油婆<>蟑螂
雀雀儿<>小鸟
照鸡儿<>蛐蛐儿
老壳<>脑袋
狭孔<>胳肢窝
手倒管儿<>手肘
磕西头儿<>膝盖
高耸耸的<>又高有胖,又高又胖
肥弄弄的<>又高有胖
烦造造的<>非常脏
短处处的<>很短
逛的<>光溜溜的
趴唧唧的<>很软
低低嘎嘎儿<>很少
飞叉叉的<>很野的样子,很野
惊抓抓的<>大惊小怪
矿西西的<>很糊涂
琛<>很直
琛抖<>非常漂亮,非常帅
登独<>非常漂亮,非常帅,帅气,黑高大,肥壮,帅
雾独独<>冷不防的
神戳戳<>发神经
念栋栋<>粘稠的
俗杂杂的<>俗气,俗气的
火瞟瞟的<>灼伤般的疼,灼伤疼
共过来<>挤过来
不拗老<>不动了
莽进去<>喂进去
咔<>掐
款到老<>碰到了
吹垮垮<>聊天,吹牛
达扑爬<>摔跤,摔跟头,正面摔倒
考可可儿<>敲一下头
打王逛<>无意识,走神,精神不集中,开小差
吧到<>紧挨着
瓦饭<>舀饭）,舀饭
过来<>跨过来
条<>跑
翻羊角转儿<>翻跟斗
捻菜<>夹菜
扯仆酣<>打呼噜
副开<>移走,用肘移走
嗨得<>吃得多
腰抬／收秤／杀鸽<>结束
板旋儿<>死不认账,说话不算数,耍赖,挣扎
哈技跟儿<>挠痒痒
脚入老<>脚崴了
菊<>吮吸
告哈儿<>试一下,试一试
舌老<>丢失了
琛过来／痴过来<>伸过来
读脚<>跺脚
咩<>掰
逞下去<>压下去
笔<>过滤
幢起<>补上
俺到<>猜到,压住
雀到<>看到
兑老<>相抵,相抵了,抵消
马起脸<>板着脸,板脸
拽瞌睡<>打瞌睡
爪球<>踢球
杀铁<>打扫
操<>翻
假巴意思<>假装,假惺惺的
窝料<>撒尿
挖爪<>脏),脏
勒里<>这里
嘿<>很
卡卡各各<>角落
低低噶噶儿<>一点点
闹热<>热闹
好多<>多少
神撮撮<>神经病
除脱<>完了,挂了,完蛋了,被人解决了,消灭
杀一脚<>坐车时叫停,做车时叫停,停车
吱<>擦),擦
剁<>顶,磋的意思
瓜西西<>傻傻的
灯儿晃<>游手好闲,无事乱逛
夹色子<>结巴
暴眼<>眼神不好,大而鼓出眼睛
诀<>骂
梭<>溜走
扫皮<>下不来台,丢脸
扯把子<>撒谎,说谎
斗室<>就是
对头<>要得,对,好,没问题
霸道惨老<>厉害,很强
清候<>念或修理人,查看,修理,调查,整理
搭巴巴车<>坐便车
要得<>好,好的,行,可以,好的,行
洋气<>气质好,新奇,很好,牛B,不得了
好黑人<>好吓人
黑哈<>很傻
搭飞白<>插话,搭讪
莫恁个<>不要这样,别这样
油济济<>很油的样子,很油,很油腻
歇<>哭,发一声
拼<>送,赠送
款到<>碰到
扛<>盖住,盖上,发三声
骇子等等儿<>鞋跟
恩脚<>咯脚
背(bēi)油<>浪费油
古<>猜测
车笔刀儿<>削笔刀
哈猴<>变质
里麻<>责备
甲甲<>身上的油垢,油垢,污垢
西得好<>幸好
排轮子<>排队
梭梭滩儿<>滑梯
再起／撩起<>缝
渠算儿<>蚯蚓
爪母儿<>蚱蜢
哈老壳<>脑袋
瞎孔<>胳肢窝
受倒管儿<>手肘
客西头儿<>膝盖
低低嘎嘎<>很少很小,很少
亮瓦瓦<>很亮
拗<>动,手脚不停地动
考可转儿<>敲一下头
扒到<>紧挨着
喀过来<>跨过来
调<>跑,调换
翻羊角砖儿<>翻跟斗
练菜<>夹菜
扯仆汉<>打呼噜
腰台／收秤／杀鸽<>结束
哈即跟儿<>挠痒痒
壁<>过滤
装起<>补齐,补上
爪瞌睡<>打瞌睡
洗白<>失败,栽了,完了,没有了,死,完蛋
喱<>踩在脚下来回擦几下
夺<>顶,刺,戳,磋
灯晃<>无事乱逛
迈<>吗
撒<>吧
决<>骂
登读<>块头大,长相不错
切<>去
撒子<>干什么
爪子<>干什么
孩子<>鞋跟
背油<>浪费油,郁闷
杯话<>不听话
车笔刀<>削笔刀
里骂<>责备
索索滩儿<>滑梯
哦尿尿<>撒尿
喝开开<>喝水
睡告告<>睡觉
吃莽莽<>吃饭
筐歪歪<>哄孩子,哄孩子睡觉
罗兜<>臀部
作登儿<>臀部
肥懂懂的<>又高又胖
锤子<>男性生殖器,不地道,不耿直,不义气
怜菜<>夹菜
骇得<>吃得多
琛过来<>伸过来
痴过来<>伸过来
状起<>补上
堂客<>老婆
车分儿<>司机
炊哥<>厨师
幺儿<>孩子
宝器<>傻瓜,笨,二楞子
杂皮<>痞子,流氓,政治小人,社会渣滓,无赖,地痞无赖,游手好闲的人
仙人板板<>粗口,骂骂咧咧,小祖宗
打飞白<>这个谁来解释
莫棱个<>不要这样
鞋子等等儿<>鞋跟
正南齐北<>我说真的
答葡爬<>摔跤
吃皮<>厉害,强大
冒皮皮<>吹牛
麦到<>以为
吃跑堂<>很多人吃饭不给钱就闪人
高头<>上面
觉底<>下面
刷把<>刷子
烧鸡<>簸箕
喘喘<>铲子,铁锹
钉锤<>锤子
牙刷<>很不够意思
瓢瓢<>勺
萝都<>筐
赶面棒<>赶面杖
奔奔儿<>围嘴
摇裤儿<>内裤
商人<>腻,吃厌了
闷油<>不想吃油腻
归于<>完毕
茅司<>厕所
岑投<>整洁,利索
梅子<>托
背时<>倒霉
空哨<>有知识,聪明
灵光<>脑子好使
精灵<>聪明
耙耳朵<>怕老婆
扎起<>撑腰
兄弟伙<>哥们
落教<>服气,义气
翻船<>出事了
妖不到台<>不好解决,不得了
提劲<>说大话,吹牛,很棒
绕包<>吹牛,说假话
妖艳<>艳丽
耙皮<>容易
耙豁<>便宜
烦<>肮脏,讨厌,恶心
豁<>哄骗,欺骗
闷声儿<>内向的人
翻胃<>想呕吐
日布龙耸<>不利索,不整洁
打整<>整理,收拾,制服人
读读儿<>底部
憨展劲<>起劲
透德行<>很行
旷眉旷眼<>一头雾水
娘娘<>阿姨,姑姑
必<>过滤
扯拐<>有毛病了,出问题
鹞子翻叉<>翻跟头
千翻儿<>捣蛋,调皮,调皮捣蛋
讨嫌<>令人讨厌
刁住<>故意
涮坛子<>不讲信用,失信
闪色子<>溜走
老汉<>爸爸
哈板儿<>傻瓜
喀喀各各<>旮旯
刹一脚<>停一下车
豆<>就
理麻<>管,干预
啥子<>什么,干什么
希得好<>幸好
债起<>缝
霸道<>牛B,了不起,很好,不得了
嘎嘎<>肉
行市<>拽,有能力
巴心不得<>正合心意,正想这样
正南其北<>不扯闲,说正经的
锄脱<>失恋,失业
卯<>有矛盾
暴挫<>很笨,很差,很丑
安逸<>舒服,满意舒服
不要<>不用谢
假打<>虚伪
拈起来<>夹起来
巴耳朵<>怕老婆
鬼儿<>小子
哈哈儿<>一会儿,马上
好多钱<>多少钱
扒到路走<>沿着路走
一哈<>全部,一下
耍朋友<>谈恋爱
摆龙门阵<>闲聊天,聊天
麻哈儿嗦<>骗傻子
浪个<>,怎样,怎么样
乖<>漂亮
哈戳戳<>傻
邙<>傻
恩是<>真的是
打望<>到处看,看美女
弄<>修理,操,打
哈麻批<>傻瓜
龟儿子<>背夫偷汉
神头儿<>神经病
牛批<>说大话
瓜吆儿<>傻儿子
老汉儿<>爸爸
幺爸<>小叔
拐子<>哥哥
兄弟<>弟弟
婆婆<>奶奶
儿娃子<>男孩
男娃儿<>男孩
女娃子<>女孩
妹娃子<>女孩
女娃儿<>女孩
假女儿<>娘娘腔
假妹仔<>娘娘腔
儿马婆<>假小子
天棒<>太保,小混混
飞石<>小太妹
扛把子<>老大
院妈娘<>老鸨
梭叶子<>妓女
告花子<>乞丐
邱二<>伙计
棒棒<>挑夫
哈儿<>傻瓜
哈子<>傻瓜
瓜娃子<>傻瓜
方脑壳<>傻瓜
木冬瓜<>傻瓜
苕货<>傻瓜
撮锅漏<>把事情搞砸的人,搞砸
好吃狗儿<>嘴馋,嘴馋的人
五香嘴<>嘴馋,嘴馋的人
豁飘<>弱不禁风,瘦而弱不禁风的人
闷墩儿<>胖人,胖而结实的人
啷杆儿<>高而瘦的人,瘦人
黄桶<>矮而胖的人,矮胖
矮大杵<>矮而胖的人,矮胖
夹舌子<>结巴
泡粑脸<>大饼脸
瓦刀脸<>鞋拔子脸,猪腰子脸
秤砣脸<>额窄颧骨高而下巴宽
磬锤脑壳<>额头特大而脸下部窄小
拉丝眼<>眼睛又小又细
板<>挣扎
板命<>拼命挣扎
打横爬<>死不认账,说话不算数
拉稀摆带<>死不认账,说话不算数
敲砂罐<>枪毙
下烂药<>背后说人坏话
出言语<>背后说人坏话
犯言<>背后说人坏话
医闷鸡<>整人,被整的人只能自认倒霉
拢<>到达
捏倒鼻子哄眼睛<>自欺欺人
装狗儿<>生病卧床或者装病
惯伺<>溺爱,纵容
玩格<>奢侈
啷个<>怎么
恁个<>这么,这样
勒<>这
高底<>上面
脚脚<>下面
底甲<>下面
好久<>什么时候
架蔑<>开始
尬事<>开始
煞角<>结束
打王广广<>开小差
日白<>说谎
扯靶子<>说谎
扯谎<>说谎
冲壳子<>吹牛
绝<>骂
日绝<>爆骂
搓-丑<>特别丑
爆搓<>特别丑,很丑
脏班子<>丢脸
臊皮<>丢脸
夺洋<>显摆
撑投<>帅气,帅
行事<>牛B,很好
扯皮<>纠纷
紧倒<>没完没了
莽起<>使劲
黑起<>使劲
搂实<>使劲
古倒<>强迫人做某事,强迫
估倒<>蹲下
居<>刺,戳
夹毛居<>穿小鞋,挤兑
黑<>吓
哇抓<>脏
龌龊<>脏
卡卡角角<>角落
水凼凼<>水坑
篾<>掰,使弯曲
月<>掰,使弯曲
点水<>告密
抵黄<>唱对台戏,当场揭穿
吃胡汉三<>请客,请客大出血
吃福喜<>请客,请客大出血
捡葩和<>占便宜
相因<>便宜
吃抹货<>白吃,白痴
看抹货<>白看
割裂<>闹矛盾
割不得人<>不好相处
矜佑<>照料,照顾
恶鸡婆<>悍妇
葩耳朵<>妻管严
老阴脉<>阴险
闷生儿<>沉默的人,沉默
么子<>什么
啷闷<>怎么
啷凯<>怎么
哩<>的
老<>了
哒<>了
哪阵<>什么时候
哪个<>谁
别个<>别人,人家
么得<>没有
倒<>着
起<>着
底哈<>底下
独独<>底部
遭<>被
呛<>像
耍<>玩
气<>去
克<>去
奇<>吃
恰<>吃
吹侉侉<>聊天
批侉卵侉<>喋喋不休
批款卵款<>喋喋不休
盯<>看
共<>钻
莽<>塞
费<>疯闹嬉戏
拗倒<>缠着不放
扭倒费<>死缠烂打
款倒<>卡住
卡<>跨过去
达<>摔,跌倒
巴<>贴,粘
巴倒<>紧挨
瓦<>舀
欧<>抠
谙倒<>估摸着
渠<>揉,磨蹭
科<>放
拼给<>送给
薅<>推
哈<>傻,挠痒痒,推
护<>推
告<>试
逞<>按
架势<>开始
尬势<>开始
收秤<>结束
提劲倒把<>吹牛
扯霍闪<>闪电
开腔<>说话
开黄腔<>瞎说
搭白<>搭话
舔肥<>拍马屁
灭<>掰
锤<>打
潮<>馋
排列子<>排队
屙粑粑<>大便
屙尿<>小便
摁<>压
打手冲<>手淫
姿<>摩擦
产<>扇耳光
耳死<>耳光
蛇<>遗失,丢
装莽<>装蒜,装傻
打牙祭<>吃好的
盘<>搬运
刁阻<>故意
搞铆<>关系破裂
拉爆<>关系破裂
抹脱<>忽略,抹杀
哈济跟儿<>胳肢
红眉毛绿眼睛<>发怒
咚<>把拖把等往水里戳
掺假水<>搞假
稀奇<>疼爱,宠爱
扯扑汗<>打鼾
发梦冲<>说梦话
嗲嗲<>爷爷
家家<>外婆
家婆<>外婆
家公<>外公
祖祖<>曾祖父母
老亲爷<>岳父
岳老头儿<>岳父
泰山<>岳父
老亲妈<>岳母
岳老婆婆儿<>岳母
泰水<>岳母
老人公<>公公
婆子妈<>婆婆
姆姆<>舅妈
伯妈<>伯母
姻伯<>女长辈
妹儿<>对年轻女子的亲热称呼
崽儿<>对年轻男子的亲热称呼
少幺爸<>太保,小混混
流尿狗儿<>尿床
莽子<>胖而结实的人
糯米老头<>老好人
外哈<>外地人
外码子<>外地人
烂眼儿<>地痞无赖,游手好闲的人
滚龙<>地痞无赖,游手好闲的人
咬卵匠<>抬杠
弯搬匠<>抬杠
岔嘴巴<>大嘴巴,包不住话
翻嘴婆<>长舌妇
爆眼子老头儿<>中年人
爆眼子老婆婆儿<>中年人
撇火药<>技术不好
黄司机<>技术不好
毛哥<>火急火燎,脾气急躁
猫师兄<>火急火燎,脾气急躁
二级钳工<>扒手
摸包客<>扒手
摸包贼<>扒手
棒客<>土匪
棒老二<>土匪
毛子<>土匪
霉冬瓜<>倒霉晦气的人
掰子<>瘸子
盘脚<>O型腿
拐脚<>X型腿
左拐子<>左撇子
蹉跎<>丑男,矬人
旷二妹<>糊涂虫
灶妈子<>蟑螂
猴三儿<>螳螂
叮叮猫儿<>蜻蜓
灶鸡儿<>蟋蟀
牵牛<>天牛
金阿子<>知了
拎阿子<>知了
丁阿子<>知了
雷公虫<>蜈蚣
革蚤<>跳蚤
蛇子<>虱子
亮花虫儿<>萤火虫
屁巴虫<>蝽,放屁虫
推屎爬<>蜣螂
金木耳<>金龟子
花姑娘<>瓢虫
新姑娘<>瓢虫
蚂丫子<>蚂蚁
旋巴虫<>鼻涕虫
螺蛳<>螺
潮冲<>蛔虫
山螺蛳<>蜗牛
猪儿虫<>毛毛虫
袢梁狗儿<>毛毛虫
活拉子<>毛毛虫
八角丁<>毛毛虫
高黄鳝<>蛇
干黄鳝<>蛇
烂草梭<>蛇
啷巴杆儿<>蛇
鱼鳅<>泥鳅
团鱼<>王八
缺块儿<>青蛙
缺妈<>青蛙
克妈<>青蛙
麻拐<>青蛙
癞格宝<>癞蛤蟆
癞克妈<>癞蛤蟆
鲫壳儿<>鲫鱼
鲇巴啷<>鲇鱼
胡子鲇<>鲇鱼
黄腊丁<>黄颡鱼
水米子<>鲮鱼
白鲢<>鲢鱼
花鲢<>胖头鱼
螃凯<>螃蟹
螃海<>螃蟹
耗子<>老鼠
耗儿<>老鼠
耗唧唧<>老鼠
鱼摆摆<>鱼
摆摆<>鱼
鸡咯咯<>鸡
鸡公<>公鸡
鸡母<>母鸡
威威<>鹅
滂臭<>很臭
帮臭<>很臭
帮臭八臭<>很臭
造孽<>可怜
造业<>可怜
撇<>不好,差
崴<>不好,差
乖桑桑<>漂亮
搓<>丑
洋盘<>牛B,很好
不摆老<>牛B,很好
巴适<>舒服
不消<>没必要
灵醒<>好看,聪明
瓜<>傻
苕<>傻,老土,庸俗
指笨<>规矩老实
怪眉日眼<>阴阳怪气,奇怪
怪头怪脑<>阴阳怪气,奇怪
绿眉绿眼<>不友好
横眉秋眼<>不友好
弯酸<>麻烦
裸连<>磨磨蹭蹭,拖泥带水
阴倒<>背地里
楼搜<>脏,邋遢
唻噻<>脏,邋遢
肉墩墩哩<>胖的,胖胖的
肉唧唧哩<>胖的,胖胖的
瘦掐掐哩<>瘦的,瘦瘦的
长梭梭哩<>长长的
短杵杵哩<>短短的
葩<>软
飞烫<>很烫
冰巴子冷<>很冷
苕大八大<>很多很大
白知八知<>不知不觉的,没来由的
练咚咚哩<>很浓稠
旷兮兮哩<>糊涂
雾独独哩<>糊涂
神戳戳哩<>神经质,疑神疑鬼
哈戳戳哩<>啥乎乎的
耿直<>够义气,爽快
俗杂杂哩<>俗气
杂豁豁哩<>不耿直,不地道
差火<>不耿直,不地道
绯红<>很红
卡白<>苍白
迅白<>很白
区黑<>黝黑
黑区妈空<>光线很暗
焦黄<>很黄
黄焦焦哩<>很黄
血古淋当<>血淋淋的
硬痴夺棒<>硬邦邦的
葩唧唧哩<>很柔软
一凶二恶<>凶巴巴的
毛焦火辣<>焦躁不安
火漂火辣<>灼痛
阴痛阴痛<>阵痛
寒贱<>爱招惹他人,不安分
手寒脚贱<>爱招惹他人,不安分
大墩墩<>大块头
小壳钻儿<>小个子
经蹦<>精力好,活泼
重皮高<>皱巴巴的
撑撑展展<>平顺
脑壳<>脑袋
眼眨毛<>睫毛
眼睛水<>眼泪
峡孔夹<>腋窝
手指母<>手指
脚趾母<>脚趾
大指母<>大拇指
中指母<>中指
幺指母<>小指
手倒拐儿<>手肘
侉子<>腿
膀<>肘子
克西头儿<>膝盖
箩篼<>屁股
坐墩儿<>屁股
沟子<>屁股
楼沟子<>屁股
咪咪<>胸部
